==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridFilterDialogOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridFilterDialogOpeningEventArgsDescription } from "./GridFilterDialogOpeningEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterDialogOpeningEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogOpeningEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogOpeningEventArgsDescriptionMetadata.a == null) {
                GridFilterDialogOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogOpeningEventArgsDescriptionMetadata.c(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridFilterDialogOpeningEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
        }
        static d(a) {
            GridFilterDialogOpeningEventArgsDescriptionMetadata.b(a);
            a.aa("GridFilterDialogOpeningEventArgs", () => new GridFilterDialogOpeningEventArgsDescription());
            a.z("GridFilterDialogOpeningEventArgs", GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterDialogOpeningEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridFilterDialogOpeningEventArgsDescriptionMetadata, 'GridFilterDialogOpeningEventArgsDescriptionMetadata');
    GridFilterDialogOpeningEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogOpeningEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridFilterDialogOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataGridColumnDescriptionMetadata } from "./DataGridColumnDescriptionMetadata";
import { GridFilterDialogOpeningEventArgsDescription } from "./GridFilterDialogOpeningEventArgsDescription";
/**
 * @hidden
 */
export let GridFilterDialogOpeningEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogOpeningEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogOpeningEventArgsDescriptionMetadata.a == null) {
                GridFilterDialogOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogOpeningEventArgsDescriptionMetadata.c(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogOpeningEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
            DataGridColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Column", "ExportedType:DataGridColumn");
        }
        static d(a) {
            GridFilterDialogOpeningEventArgsDescriptionMetadata.b(a);
            a.ac("GridFilterDialogOpeningEventArgs", () => new GridFilterDialogOpeningEventArgsDescription());
            a.ab("GridFilterDialogOpeningEventArgs", GridFilterDialogOpeningEventArgsDescriptionMetadata.a);
        }
    }
    GridFilterDialogOpeningEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridFilterDialogOpeningEventArgsDescriptionMetadata, 'GridFilterDialogOpeningEventArgsDescriptionMetadata');
    GridFilterDialogOpeningEventArgsDescriptionMetadata.a = null;
    return GridFilterDialogOpeningEventArgsDescriptionMetadata;
})();
